PayloadType<T> class abstract

The base class for any payload type. It is capable of reading and writing values to a PayloadWriter or PayloadReader.

Each PayloadType handles it's own packing and unpacking of bytes.

Implementers

Constructors

PayloadType()
The base class for any payload type. It is capable of reading and writing values to a PayloadWriter or PayloadReader.
const

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

get(ByteReader reader, [Endian? endian]) → T
Retrieve the value from the reader.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
set(ByteWriter writer, T value, [Endian? endian]) → void
Set the value in the writer.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited